package cn.com.infosec.jce;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.nist.NISTNamedCurves;
import cn.com.infosec.asn1.sec.SECNamedCurves;
import cn.com.infosec.asn1.teletrust.TeleTrusTNamedCurves;
import cn.com.infosec.asn1.x9.X962NamedCurves;
import cn.com.infosec.asn1.x9.X9ECParameters;
import cn.com.infosec.jce.spec.ECNamedCurveParameterSpec;
import cn.com.infosec.math.ec.ECCurve;
import cn.com.infosec.math.ec.ECPoint;
import java.math.BigInteger;
import java.util.Enumeration;
import java.util.Vector;

public class ECNamedCurveTable {
   public static ECNamedCurveParameterSpec getParameterSpec(String name) {
      X9ECParameters var10000;
      X9ECParameters var1;
      if ((var1 = X962NamedCurves.getByName(name)) == null) {
         label45: {
            try {
               var10000 = X962NamedCurves.getByOID(new DERObjectIdentifier(name));
            } catch (IllegalArgumentException var8) {
               break label45;
            }

            var1 = var10000;
         }
      }

      if (var1 == null && (var1 = SECNamedCurves.getByName(name)) == null) {
         label39: {
            try {
               var10000 = SECNamedCurves.getByOID(new DERObjectIdentifier(name));
            } catch (IllegalArgumentException var7) {
               break label39;
            }

            var1 = var10000;
         }
      }

      if (var1 == null && (var1 = TeleTrusTNamedCurves.getByName(name)) == null) {
         label33: {
            try {
               var10000 = TeleTrusTNamedCurves.getByOID(new DERObjectIdentifier(name));
            } catch (IllegalArgumentException var6) {
               break label33;
            }

            var1 = var10000;
         }
      }

      if (var1 == null) {
         var1 = NISTNamedCurves.getByName(name);
      }

      if (var1 == null) {
         return null;
      } else {
         X9ECParameters var10002 = var1;
         X9ECParameters var10003 = var1;
         X9ECParameters var10004 = var1;
         X9ECParameters var10005 = var1;
         ECCurve var9 = var1.getCurve();
         ECPoint var2 = var10005.getG();
         BigInteger var3 = var10004.getN();
         BigInteger var4 = var10003.getH();
         byte[] var5 = var10002.getSeed();
         return new ECNamedCurveParameterSpec(name, var9, var2, var3, var4, var5);
      }
   }

   public static Enumeration getNames() {
      Vector var10000 = new Vector();
      addEnumeration(var10000, X962NamedCurves.getNames());
      addEnumeration(var10000, SECNamedCurves.getNames());
      addEnumeration(var10000, NISTNamedCurves.getNames());
      addEnumeration(var10000, TeleTrusTNamedCurves.getNames());
      return var10000.elements();
   }

   private static void addEnumeration(Vector v, Enumeration e) {
      while(e.hasMoreElements()) {
         v.addElement(e.nextElement());
      }

   }
}
